# fedfind

Fedora Finder finds Fedoras.

## Licensing

Fedora Finder itself is available under the GPL, version 3 or any
later version. A copy is included as COPYING.

Currently it includes a copy of cached-property by Daniel
Greenfield, which is licensed under the BSD license, included as
LICENSE.cached-property.

https://pypi.python.org/pypi/cached-property
